@@ -8,8 +8,11 @@ from tempfile import TemporaryDirectory
 import argparse
 from pathlib import Path
 import logging
-
-__version__ = "0.1.0"
+try:
+    from importlib.metadata import version
+    __version__ = version("d3-cli")
+except Exception:
+    __version__ = "local dev version"
 
 
 def cli(argv=None):
@@ -21,46 +24,59 @@ def cli(argv=None):
     parser.add_argument(
         "input",
         nargs="*",
-        help="Folders containing D3 YAML files.",
+        help="folders containing D3 YAML files.",
         default=[],
         type=Path,
     )
+    parser.add_argument(
+        "--version", action="store_true", help="show the version and exit.",
+    )
+    parser.add_argument(
+        "--guid",
+        "--uuid",
+        action="store_true",
+        help="generate and show guid and exit.",
+    )
+    parser.add_argument(
+        "--output",
+        nargs="?",
+        help="directory in which to output built claims.",
+        default=Path.cwd() / "d3-build",
+        type=Path,
+    )
     parser.add_argument(
         "--mode",
         "-m",
         nargs="?",
-        help="Mode to run d3-cli in.",
+        help="mode to run d3-cli in.",
         default="build",
         choices=["build", "lint", "export"],
     )
     parser.add_argument(
-        "--version", action="store_true", help="Show the version and exit.",
-    )
-    parser.add_argument(
-        "--guid",
-        "--uuid",
+        "--skip-vuln",
         action="store_true",
-        help="Generate and show guid and exit.",
+        help="""skip vulnerability lookup.
+        This takes a long time, and requires an internet connection
+        so you may wish to skip this step for local testing.""",
     )
     parser.add_argument(
-        "--output",
-        nargs="?",
-        help="Directory in which to output built claims.",
-        default=Path.cwd(),
-        type=Path,
+        "--skip-mal",
+        action="store_true",
+        help="""skip malicious url lookup.
+        This takes a bit of time, and requires an internet connection
+        so you may wish to skip this step for local testing.""",
     )
     parser.add_argument(
         "--build-dir",
         nargs="?",
-        help="""Build directory with json claims to export.
+        help="""build directory with json claims to export.
         Specifying this will skip build step in export mode.""",
-        default=Path.cwd(),
         type=Path,
     )
     parser.add_argument(
         "--check_uri_resolves",
         action="store_true",
-        help="""Check that URIs/refs resolve.
+        help="""check that URIs/refs resolve.
         This can be very slow, so you may want to leave this off normally.""",
     )
 
@@ -75,8 +91,7 @@ def cli(argv=None):
     args = parser.parse_args(argv)
 
     if args.version:
-        # TODO: check this version number is correct when installed
-        logging.info(f"d3-cli, version {__version__}")
+        print(f"d3-cli, version {__version__}")
         return
 
     if args.guid:
@@ -86,7 +101,8 @@ def cli(argv=None):
     log_level_sum = min(sum(args.log_level or tuple(), logging.INFO), logging.ERROR)
     logging.basicConfig(level=log_level_sum)
 
-    if len(args.input) == 0:
+    export_only = (args.build_dir is not None and args.mode == "export")
+    if len(args.input) == 0 and not export_only:
         logging.warning("No directories provided, Exiting...")
         return
 
@@ -101,25 +117,20 @@ def cli(argv=None):
                 for d3_file in d3_folder.glob("**/*.yaml")
             )
         )
-
-        try:
-            validate_d3_claim_files(
-                d3_files, check_uri_resolves=args.check_uri_resolves
-            )
-        except Exception as error:
-            logging.error(error)
+        validate_d3_claim_files(
+            d3_files, check_uri_resolves=args.check_uri_resolves
+        )
         logging.info("All files passed linting successfully.")
 
     elif args.mode == "build":
         logging.info("building")
-        try:
-            d3_build(
-                d3_folders=args.input,
-                output_dir=args.output,
-                check_uri_resolves=args.check_uri_resolves,
-            )
-        except Exception as error:
-            logging.error(error)
+        d3_build(
+            d3_folders=args.input,
+            output_dir=args.output,
+            check_uri_resolves=args.check_uri_resolves,
+            skip_vuln=args.skip_vuln,
+            skip_mal=args.skip_mal,
+        )
 
     elif args.mode == "export":
         logging.info("exporting")
@@ -130,18 +141,15 @@ def cli(argv=None):
         else:
             temp_dir = TemporaryDirectory()
             build_dir = Path(temp_dir.name)
-            try:
-                d3_build(
-                    d3_folders=args.input,
-                    output_dir=build_dir,
-                    check_uri_resolves=args.check_uri_resolves,
-                )
-            except Exception as error:
-                logging.error(error)
-        try:
-            d3_build_db(build_dir, args.output)
-        except Exception as error:
-            logging.error(error)
+            d3_build(
+                d3_folders=args.input,
+                output_dir=build_dir,
+                check_uri_resolves=args.check_uri_resolves,
+                skip_vuln=args.skip_vuln,
+                skip_mal=args.skip_mal,
+            )
+
+        d3_build_db(build_dir, args.output)
         try:
             temp_dir.cleanup()
         except NameError:
